"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const graphql_1 = require("graphql");
const Argument_1 = __importDefault(require("./Argument"));
const MarkdownContent_1 = __importDefault(require("./MarkdownContent"));
const TypeLink_1 = __importDefault(require("./TypeLink"));
const DefaultValue_1 = __importDefault(require("./DefaultValue"));
class TypeDoc extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.handleShowDeprecated = () => this.setState({ showDeprecated: true });
        this.state = { showDeprecated: false };
    }
    shouldComponentUpdate(nextProps, nextState) {
        return (this.props.type !== nextProps.type ||
            this.props.schema !== nextProps.schema ||
            this.state.showDeprecated !== nextState.showDeprecated);
    }
    render() {
        const schema = this.props.schema;
        const type = this.props.type;
        const onClickType = this.props.onClickType;
        const onClickField = this.props.onClickField;
        let typesTitle = null;
        let types = [];
        if (type instanceof graphql_1.GraphQLUnionType) {
            typesTitle = 'possible types';
            types = schema.getPossibleTypes(type);
        }
        else if (type instanceof graphql_1.GraphQLInterfaceType) {
            typesTitle = 'implementations';
            types = schema.getPossibleTypes(type);
        }
        else if (type instanceof graphql_1.GraphQLObjectType) {
            typesTitle = 'implements';
            types = type.getInterfaces();
        }
        let typesDef;
        if (types && types.length > 0) {
            typesDef = (<div className="doc-category">
          <div className="doc-category-title">{typesTitle}</div>
          {types.map(subtype => (<div key={subtype.name} className="doc-category-item">
              <TypeLink_1.default type={subtype} onClick={onClickType}/>
            </div>))}
        </div>);
        }
        let fieldsDef;
        let deprecatedFieldsDef;
        if ('getFields' in type) {
            const fieldMap = type.getFields();
            const fields = Object.keys(fieldMap).map(name => fieldMap[name]);
            fieldsDef = (<div className="doc-category">
          <div className="doc-category-title">{'fields'}</div>
          {fields
                .filter(field => 'isDeprecated' in field ? !field.isDeprecated : true)
                .map(field => (<Field key={field.name} type={type} field={field} onClickType={onClickType} onClickField={onClickField}/>))}
        </div>);
            const deprecatedFields = fields.filter(field => 'isDeprecated' in field ? field.isDeprecated : true);
            if (deprecatedFields.length > 0) {
                deprecatedFieldsDef = (<div className="doc-category">
            <div className="doc-category-title">{'deprecated fields'}</div>
            {!this.state.showDeprecated ? (<button className="show-btn" onClick={this.handleShowDeprecated}>
                {'Show deprecated fields...'}
              </button>) : (deprecatedFields.map(field => (<Field key={field.name} type={type} field={field} onClickType={onClickType} onClickField={onClickField}/>)))}
          </div>);
            }
        }
        let valuesDef;
        let deprecatedValuesDef;
        if (type instanceof graphql_1.GraphQLEnumType) {
            const values = type.getValues();
            valuesDef = (<div className="doc-category">
          <div className="doc-category-title">{'values'}</div>
          {values
                .filter(value => !value.isDeprecated)
                .map(value => (<EnumValue key={value.name} value={value}/>))}
        </div>);
            const deprecatedValues = values.filter(value => value.isDeprecated);
            if (deprecatedValues.length > 0) {
                deprecatedValuesDef = (<div className="doc-category">
            <div className="doc-category-title">{'deprecated values'}</div>
            {!this.state.showDeprecated ? (<button className="show-btn" onClick={this.handleShowDeprecated}>
                {'Show deprecated values...'}
              </button>) : (deprecatedValues.map(value => (<EnumValue key={value.name} value={value}/>)))}
          </div>);
            }
        }
        return (<div>
        <MarkdownContent_1.default className="doc-type-description" markdown={('description' in type && type.description) || 'No Description'}/>
        {type instanceof graphql_1.GraphQLObjectType && typesDef}
        {fieldsDef}
        {deprecatedFieldsDef}
        {valuesDef}
        {deprecatedValuesDef}
        {!(type instanceof graphql_1.GraphQLObjectType) && typesDef}
      </div>);
    }
}
exports.default = TypeDoc;
function Field({ type, field, onClickType, onClickField }) {
    return (<div className="doc-category-item">
      <a className="field-name" onClick={event => onClickField(field, type, event)}>
        {field.name}
      </a>
      {'args' in field &&
        field.args &&
        field.args.length > 0 && [
        '(',
        <span key="args">
            {field.args.map(arg => (<Argument_1.default key={arg.name} arg={arg} onClickType={onClickType}/>))}
          </span>,
        ')',
    ]}
      {': '}
      <TypeLink_1.default type={field.type} onClick={onClickType}/>
      <DefaultValue_1.default field={field}/>
      {field.description && (<MarkdownContent_1.default className="field-short-description" markdown={field.description}/>)}
      {'deprecationReason' in field && field.deprecationReason && (<MarkdownContent_1.default className="doc-deprecation" markdown={field.deprecationReason}/>)}
    </div>);
}
function EnumValue({ value }) {
    return (<div className="doc-category-item">
      <div className="enum-value">{value.name}</div>
      <MarkdownContent_1.default className="doc-value-description" markdown={value.description}/>
      {value.deprecationReason && (<MarkdownContent_1.default className="doc-deprecation" markdown={value.deprecationReason}/>)}
    </div>);
}
//# sourceMappingURL=TypeDoc.jsx.map