"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const react_1 = __importDefault(require("react"));
const QueryStore_1 = __importDefault(require("../utility/QueryStore"));
const HistoryQuery_1 = __importDefault(require("./HistoryQuery"));
const MAX_QUERY_SIZE = 100000;
const MAX_HISTORY_LENGTH = 20;
const shouldSaveQuery = (query, variables, lastQuerySaved) => {
    if (!query) {
        return false;
    }
    try {
        graphql_1.parse(query);
    }
    catch (e) {
        return false;
    }
    if (query.length > MAX_QUERY_SIZE) {
        return false;
    }
    if (!lastQuerySaved) {
        return true;
    }
    if (JSON.stringify(query) === JSON.stringify(lastQuerySaved.query)) {
        if (JSON.stringify(variables) === JSON.stringify(lastQuerySaved.variables)) {
            return false;
        }
        if (variables && !lastQuerySaved.variables) {
            return false;
        }
    }
    return true;
};
class QueryHistory extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.updateHistory = (query, variables, operationName) => {
            if (shouldSaveQuery(query, variables, this.historyStore.fetchRecent())) {
                this.historyStore.push({
                    query,
                    variables,
                    operationName,
                });
                const historyQueries = this.historyStore.items;
                const favoriteQueries = this.favoriteStore.items;
                const queries = historyQueries.concat(favoriteQueries);
                this.setState({
                    queries,
                });
            }
        };
        this.toggleFavorite = (query, variables, operationName, label, favorite) => {
            const item = {
                query,
                variables,
                operationName,
                label,
            };
            if (!this.favoriteStore.contains(item)) {
                item.favorite = true;
                this.favoriteStore.push(item);
            }
            else if (favorite) {
                item.favorite = false;
                this.favoriteStore.delete(item);
            }
            this.setState({
                queries: [...this.historyStore.items, ...this.favoriteStore.items],
            });
        };
        this.editLabel = (query, variables, operationName, label, favorite) => {
            const item = {
                query,
                variables,
                operationName,
                label,
            };
            if (favorite) {
                this.favoriteStore.edit({ ...item, favorite });
            }
            else {
                this.historyStore.edit(item);
            }
            this.setState({
                queries: [...this.historyStore.items, ...this.favoriteStore.items],
            });
        };
        this.historyStore = new QueryStore_1.default('queries', props.storage, MAX_HISTORY_LENGTH);
        this.favoriteStore = new QueryStore_1.default('favorites', props.storage, null);
        const historyQueries = this.historyStore.fetchAll();
        const favoriteQueries = this.favoriteStore.fetchAll();
        const queries = historyQueries.concat(favoriteQueries);
        this.state = { queries };
    }
    render() {
        const queries = this.state.queries.slice().reverse();
        const queryNodes = queries.map((query, i) => {
            return (<HistoryQuery_1.default handleEditLabel={this.editLabel} handleToggleFavorite={this.toggleFavorite} key={`${i}:${query.label || query.query}`} onSelect={this.props.onSelectQuery} {...query}/>);
        });
        return (<section aria-label="History">
        <div className="history-title-bar">
          <div className="history-title">{'History'}</div>
          <div className="doc-explorer-rhs">{this.props.children}</div>
        </div>
        <ul className="history-contents">{queryNodes}</ul>
      </section>);
    }
}
exports.QueryHistory = QueryHistory;
//# sourceMappingURL=QueryHistory.jsx.map