"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const commonKeys_1 = __importDefault(require("../utility/commonKeys"));
class ResultViewer extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.viewer = null;
        this._node = null;
    }
    componentDidMount() {
        const CodeMirror = require('codemirror');
        require('codemirror/addon/fold/foldgutter');
        require('codemirror/addon/fold/brace-fold');
        require('codemirror/addon/dialog/dialog');
        require('codemirror/addon/search/search');
        require('codemirror/addon/search/searchcursor');
        require('codemirror/addon/search/jump-to-line');
        require('codemirror/keymap/sublime');
        require('codemirror-graphql/results/mode');
        const Tooltip = this.props.ResultsTooltip;
        const ImagePreview = this.props.ImagePreview;
        if (Tooltip || ImagePreview) {
            require('codemirror-graphql/utils/info-addon');
            const tooltipDiv = document.createElement('div');
            CodeMirror.registerHelper('info', 'graphql-results', (token, _options, _cm, pos) => {
                const infoElements = [];
                if (Tooltip) {
                    infoElements.push(<Tooltip pos={pos}/>);
                }
                if (ImagePreview &&
                    typeof ImagePreview.shouldRender === 'function' &&
                    ImagePreview.shouldRender(token)) {
                    infoElements.push(<ImagePreview token={token}/>);
                }
                if (!infoElements.length) {
                    react_dom_1.default.unmountComponentAtNode(tooltipDiv);
                    return null;
                }
                react_dom_1.default.render(<div>{infoElements}</div>, tooltipDiv);
                return tooltipDiv;
            });
        }
        this.viewer = CodeMirror(this._node, {
            lineWrapping: true,
            value: this.props.value || '',
            readOnly: true,
            theme: this.props.editorTheme || 'graphiql',
            mode: 'graphql-results',
            keyMap: 'sublime',
            foldGutter: {
                minFoldSize: 4,
            },
            gutters: ['CodeMirror-foldgutter'],
            info: Boolean(this.props.ResultsTooltip || this.props.ImagePreview),
            extraKeys: commonKeys_1.default,
        });
    }
    shouldComponentUpdate(nextProps) {
        return this.props.value !== nextProps.value;
    }
    componentDidUpdate() {
        if (this.viewer) {
            this.viewer.setValue(this.props.value || '');
        }
    }
    componentWillUnmount() {
        this.viewer = null;
    }
    render() {
        return (<section className="result-window" aria-label="Result Window" aria-live="polite" aria-atomic="true" ref={node => {
            if (node) {
                this.props.registerRef(node);
                this._node = node;
            }
        }}/>);
    }
    getCodeMirror() {
        return this.viewer;
    }
    getClientHeight() {
        return this._node && this._node.clientHeight;
    }
}
exports.ResultViewer = ResultViewer;
//# sourceMappingURL=ResultViewer.jsx.map