"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
function getQueryFacts(schema, documentStr) {
    if (!documentStr) {
        return;
    }
    let documentAST;
    try {
        documentAST = graphql_1.parse(documentStr);
    }
    catch {
        return;
    }
    const variableToType = schema
        ? collectVariables(schema, documentAST)
        : undefined;
    const operations = [];
    documentAST.definitions.forEach(def => {
        if (def.kind === 'OperationDefinition') {
            operations.push(def);
        }
    });
    return { variableToType, operations };
}
exports.default = getQueryFacts;
function collectVariables(schema, documentAST) {
    const variableToType = Object.create(null);
    documentAST.definitions.forEach(definition => {
        if (definition.kind === 'OperationDefinition') {
            const variableDefinitions = definition.variableDefinitions;
            if (variableDefinitions) {
                variableDefinitions.forEach(({ variable, type }) => {
                    const inputType = graphql_1.typeFromAST(schema, type);
                    if (inputType) {
                        variableToType[variable.name.value] = inputType;
                    }
                });
            }
        }
    });
    return variableToType;
}
exports.collectVariables = collectVariables;
//# sourceMappingURL=getQueryFacts.js.map