"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
function uniqueBy(array, iteratee) {
    const FilteredMap = new Map();
    const result = [];
    for (const item of array) {
        const uniqeValue = iteratee(item);
        if (!FilteredMap.has(uniqeValue)) {
            FilteredMap.set(uniqeValue, true);
            result.push(item);
        }
    }
    return result;
}
exports.uniqueBy = uniqueBy;
function mergeAST(documentAST) {
    const fragmentDefinitions = Object.create(null);
    for (const definition of documentAST.definitions) {
        if (definition.kind === 'FragmentDefinition') {
            fragmentDefinitions[definition.name.value] = definition;
        }
    }
    return graphql_1.visit(documentAST, {
        FragmentSpread(node) {
            return {
                ...fragmentDefinitions[node.name.value],
                kind: 'InlineFragment',
            };
        },
        SelectionSet(node) {
            return {
                ...node,
                selections: uniqueBy(node.selections, selection => selection.name.value),
            };
        },
        FragmentDefinition() {
            return null;
        },
    });
}
exports.default = mergeAST;
//# sourceMappingURL=mergeAst.js.map