"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const CodeMirror = __importStar(require("codemirror"));
const graphql_1 = require("graphql");
const markdown_it_1 = __importDefault(require("markdown-it"));
const md = new markdown_it_1.default();
function onHasCompletion(_cm, data, onHintInformationRender) {
    let information;
    let deprecation;
    CodeMirror.on(data, 'select', (ctx, el) => {
        if (!information) {
            const hintsUl = el.parentNode;
            information = document.createElement('div');
            information.className = 'CodeMirror-hint-information';
            hintsUl.appendChild(information);
            deprecation = document.createElement('div');
            deprecation.className = 'CodeMirror-hint-deprecation';
            hintsUl.appendChild(deprecation);
            let onRemoveFn;
            hintsUl.addEventListener('DOMNodeRemoved', (onRemoveFn = (event) => {
                if (event.target === hintsUl) {
                    hintsUl.removeEventListener('DOMNodeRemoved', onRemoveFn);
                    information = null;
                    deprecation = null;
                    onRemoveFn = null;
                }
            }));
        }
        const description = ctx.description
            ? md.render(ctx.description)
            : 'Self descriptive.';
        const type = ctx.type
            ? '<span class="infoType">' + renderType(ctx.type) + '</span>'
            : '';
        information.innerHTML =
            '<div class="content">' +
                (description.slice(0, 3) === '<p>'
                    ? '<p>' + type + description.slice(3)
                    : type + description) +
                '</div>';
        if (ctx && deprecation && ctx.isDeprecated) {
            const reason = ctx.deprecationReason
                ? md.render(ctx.deprecationReason)
                : '';
            deprecation.innerHTML =
                '<span class="deprecation-label">Deprecated</span>' + reason;
            deprecation.style.display = 'block';
        }
        else if (deprecation) {
            deprecation.style.display = 'none';
        }
        if (onHintInformationRender) {
            onHintInformationRender(information);
        }
    });
}
exports.default = onHasCompletion;
function renderType(type) {
    if (type instanceof graphql_1.GraphQLNonNull) {
        return `${renderType(type.ofType)}!`;
    }
    if (type instanceof graphql_1.GraphQLList) {
        return `[${renderType(type.ofType)}]`;
    }
    return `<a class="typeName">${type.name}</a>`;
}
//# sourceMappingURL=onHasCompletion.js.map