function isQuotaError(storage, e) {
    return (e instanceof DOMException &&
        (e.code === 22 ||
            e.code === 1014 ||
            e.name === 'QuotaExceededError' ||
            e.name === 'NS_ERROR_DOM_QUOTA_REACHED') &&
        storage.length !== 0);
}
export default class StorageAPI {
    constructor(storage) {
        this.storage =
            storage || (typeof window !== 'undefined' ? window.localStorage : null);
    }
    get(name) {
        if (this.storage) {
            const value = this.storage.getItem('graphiql:' + name);
            if (value === 'null' || value === 'undefined') {
                this.storage.removeItem('graphiql:' + name);
                return null;
            }
            if (value) {
                return value;
            }
        }
        return null;
    }
    set(name, value) {
        let quotaError = false;
        let error = null;
        if (this.storage) {
            const key = `graphiql:${name}`;
            if (value) {
                try {
                    this.storage.setItem(key, value);
                }
                catch (e) {
                    error = e;
                    quotaError = isQuotaError(this.storage, e);
                }
            }
            else {
                this.storage.removeItem(key);
            }
        }
        return {
            isQuotaError: quotaError,
            error,
        };
    }
}
//# sourceMappingURL=StorageAPI.js.map