import { parse, typeFromAST, } from 'graphql';
export default function getQueryFacts(schema, documentStr) {
    if (!documentStr) {
        return;
    }
    let documentAST;
    try {
        documentAST = parse(documentStr);
    }
    catch {
        return;
    }
    const variableToType = schema
        ? collectVariables(schema, documentAST)
        : undefined;
    const operations = [];
    documentAST.definitions.forEach(def => {
        if (def.kind === 'OperationDefinition') {
            operations.push(def);
        }
    });
    return { variableToType, operations };
}
export function collectVariables(schema, documentAST) {
    const variableToType = Object.create(null);
    documentAST.definitions.forEach(definition => {
        if (definition.kind === 'OperationDefinition') {
            const variableDefinitions = definition.variableDefinitions;
            if (variableDefinitions) {
                variableDefinitions.forEach(({ variable, type }) => {
                    const inputType = typeFromAST(schema, type);
                    if (inputType) {
                        variableToType[variable.name.value] = inputType;
                    }
                });
            }
        }
    });
    return variableToType;
}
//# sourceMappingURL=getQueryFacts.js.map