import * as CodeMirror from 'codemirror';
import { GraphQLNonNull, GraphQLList, } from 'graphql';
import MD from 'markdown-it';
const md = new MD();
export default function onHasCompletion(_cm, data, onHintInformationRender) {
    let information;
    let deprecation;
    CodeMirror.on(data, 'select', (ctx, el) => {
        if (!information) {
            const hintsUl = el.parentNode;
            information = document.createElement('div');
            information.className = 'CodeMirror-hint-information';
            hintsUl.appendChild(information);
            deprecation = document.createElement('div');
            deprecation.className = 'CodeMirror-hint-deprecation';
            hintsUl.appendChild(deprecation);
            let onRemoveFn;
            hintsUl.addEventListener('DOMNodeRemoved', (onRemoveFn = (event) => {
                if (event.target === hintsUl) {
                    hintsUl.removeEventListener('DOMNodeRemoved', onRemoveFn);
                    information = null;
                    deprecation = null;
                    onRemoveFn = null;
                }
            }));
        }
        const description = ctx.description
            ? md.render(ctx.description)
            : 'Self descriptive.';
        const type = ctx.type
            ? '<span class="infoType">' + renderType(ctx.type) + '</span>'
            : '';
        information.innerHTML =
            '<div class="content">' +
                (description.slice(0, 3) === '<p>'
                    ? '<p>' + type + description.slice(3)
                    : type + description) +
                '</div>';
        if (ctx && deprecation && ctx.isDeprecated) {
            const reason = ctx.deprecationReason
                ? md.render(ctx.deprecationReason)
                : '';
            deprecation.innerHTML =
                '<span class="deprecation-label">Deprecated</span>' + reason;
            deprecation.style.display = 'block';
        }
        else if (deprecation) {
            deprecation.style.display = 'none';
        }
        if (onHintInformationRender) {
            onHintInformationRender(information);
        }
    });
}
function renderType(type) {
    if (type instanceof GraphQLNonNull) {
        return `${renderType(type.ofType)}!`;
    }
    if (type instanceof GraphQLList) {
        return `[${renderType(type.ofType)}]`;
    }
    return `<a class="typeName">${type.name}</a>`;
}
//# sourceMappingURL=onHasCompletion.js.map